#
# spec file for package flamp
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           flamp
Version:        2.2.13
Release:        lp160.2.2
Summary:        Amateur Multicast Protocol - file transfer program
License:        GPL-2.0
Group:          Productivity/Hamradio/Other
URL:            http://www.w1hkj.com/
#Git-Clone:     https://git.code.sf.net/p/fldigi/flamp
Source:         http://sourceforge.net/projects/fldigi/files/%{name}/%{name}-%{version}.tar.gz
BuildRequires:  fltk-devel
BuildRequires:  flxmlrpc-devel
BuildRequires:  gcc-c++
BuildRequires:  update-desktop-files
Requires(post): update-desktop-files
Requires(postun): update-desktop-files

%description
FLAMP is a program for AMP or Amateur Multicast Protocol. An FLAMP session will
transmit one or more files with one or more iterations of the transmission. Each
file is broken into blocks, each of which has a check sum. The receiving station
saves the blocks that pass check sum. Successive transmissions will fill in the
missing blocks provided that the new blocks pass the check sum. After the
transmission sequence, the entire file is assembled and may be saved. “Fills”
may be provided by retransmitting the entire file or by the sending station
only sending the missing blocks. 

%prep
%setup -q

%build
export BUILD_DATE=`date -d@0`
export BUILD_USER=openSUSE
export BUILD_HOST=openSUSE
%configure
%make_build

%install
%make_install

%suse_update_desktop_file -i flamp

%files
%license COPYING
%doc AUTHORS ChangeLog README
%{_bindir}/flamp
%{_datadir}/applications/flamp.desktop
%{_datadir}/pixmaps/flamp.xpm

%changelog
* Wed Jul 10 2024 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 2.2.13
  * Document/GUI/Header Modem/Default Modems
    + Update User Manual for recent changes.
    + Estimated Relay transmit time not updating on TX panel modem change.
    + Header Modem using interval timer RX state delay, corrected.
    + Olivia Modem Names to Uppercase.
    + Remove redundant TX_SEGMENTED check.
    + Add code for relay repeat counters, interval timer.
* Sun Apr 21 2024 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 2.2.12
  * Tabs/Relay Options/GUI/Fluid
    + Save selected Tab panel state on exit
    + Restore selected panel on restart.
    + Corrected Widget Event Settings (FLUID).
    + Add Header/Data Repeat Counters for Relay file transmissions.
    + Add transmit time widget for relay files.
    + Move relay auto save checkboxes to config panel.
    + Corrected default Olivia modem tag names.
    + Add code to correctly restore RX panel data on file selection
    changes.
  * font browser
    + update font browser class to use std::list vice computed
    array size to enumerate system fonts
  * Document/GUI/Header Modem/Default Modems
    + Update User Manual for recent changes.
    + Estimated Relay transmit time not updating on TX panel modem
    change.
    + Header Modem using interval timer RX state delay, corrected.
    + Olivia Modem Names to Uppercase.
    + Remove redundant TX_SEGMENTED check.
    + Add code for relay repeat counters, interval timer.
  * Compatibility/Modem Switch
    + Add leading linefeed to [bxx:end] tags
    + Add delay to allow FLDIGI the time to switch modems
* Sun Dec 31 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 2.2.11
  * Add code to save interval timer values
  * Adjust GUI widget alignment
  * Update user documents
* Sun Nov  5 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 2.2.10
  * Relay/Check Saves
    + Change load relay file at start to a menu item. Odd GUI
    behaviour on MacOSX 10.15.
    + Add save relay data menu item.
    + Check RX panel file for 100%% complete prior to saving.
    + Rename checkbox to save relay files on exit. Removed load at
    start code.
  * rs df merge: merge KK5VD and W1HKJ independent mods
  * Online Conditions/Thread locks
    + Restore code lost.
    + Add code to indicate FLDIGI is online when both data stream
    and XMLRPC are actively connected between FLAMP and FLDIGI.
    + Use guard_lock class in place of pthread_mutex locks.
  * RX Panel/GUI cosmetic
    + Add callback function cb_rx_queue to rx_queue widget via FLUID.
    + Changed RX panel redraw from entire panel to specific widgets.
  * Font display artifacts issue when redrawing RX panel.
    + Adjust position/size of various widgets (cosmetic).
    + Removed some commented out code.
    + Prevent 100%% save (if selected) when reloading relay files.
    + Issue get_fldigi_modems() on reconnects to FLDIGI.
  * UI design: change user interface design to use fluid definition file
  * TOD implementation merge with branch pu/rs
    + change to operate in a separate thread
    + allow flamp to run without fldigi executing
    + periodically test main dialog indicator of connection state
    for and make connection to fldigi
    + use single exit point from program
  * Replay/XMLRPC/M4/Modem/Documentation/GUI
    + Add "modem.get_io_names" Prefiltered 8 bit compatible modem
    listfrom FLDIGI.
    + Update depreciated M4 macros.
    + Update modem timimg table based on "modem.get_io_names" input.
    + Add Receive Queue data/retore option for Relay Ops.
    + Remove depreciated modem List.
    + Append depreciated list to initial start-up modem list.
    + GUI Interval timer widget position change.
    + HAMCAST broke on XMLRPC timeout change, updated wait_for_rx().
    + Add dummy file to keep directory "build-aux" in the git tree.
    + New "relay" directory to store saved relay data. (.nbmes/FLAMP/relay)
    + Updated scripting to handle dynamic modem list verification testing.
    + Remove depreciated default modem names no longer present in FLDIGI.
    + Update user document based on above changes.
* Sun Sep  3 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 2.2.09
  * Update to documentation received from Rich, N1EE
  * Add THOR-11, THOR-32, THOR-44 and THOR-56 to list of supported
    modes
  * Text Editor mod: fix for compiler warning
  * xmlrpc server
    + add xmlrpc server to support external creation and execution
    of flamp script files
    . "flamp.create_script", "i:s", "create script 'pathname', 'script_text'"
    . "flamp.execute_script", "n:s", "execute script 'pathname'"
  * fltk 1.4.x mods: compatability modifications
  * Main Window Icon: fix Fltk transparency bug for flrig icon.
- update to version 2.2.08
  * Fix logic error in transmit_camp.cxx
  * deprecate "using namespace std" to prevent name conflicts
    with g++ c11.
  * User Interface - Combobox fixes
    . Fixed several edge case behaviors with Combobox widgets
* Thu Jun 29 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- fix build for Tumbleweed and Factory
- New specfile based on fldigi specflie
* Sun Aug 15 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 2.2.07
  * fix tagSearch logic error introduced with openSUSE Tumbleweed
    modifications
- update to version 2.2.06
  * add XmlRpc client ID
  * fix errors and warnings exposed by gcc 11.1.1
  * change fltk.m4 to accept version 1.4.x
  * changes to data i/o query timing
  * increase timeouts for xml
  MXE build
  * remove regex from build
  fldigi i/o
  * changes to data i/o query timing
* Mon Jul 29 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 2.2.05
  * limit sock block size to 8096 for transfer to fldigi
  * add time interval between blocks to allow receiving
    socket to flush it's receive buffers
  * clean up warnings
  * add LOG_INFO statements to transfer function
  * correct computation of time intervals
  * changed FLAMP SCRIPT variable TX_INTERVAL to float
  * update documentation
* Sun Feb  3 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 2.2.04
* Sat Apr 30 2016 dl8fcl@t-online.de
- update to version 2.2.03
* Tue Apr 28 2015 dl8fcl@darc.de
- update to version 2.2.02
  requires libflxmlrpc
* Sat Apr  4 2015 dl8fcl@darc.de
- update to version 2.2.01
* Fri Dec 26 2014 dl8fcl@darc.de
- update to version 2.2.00
* Tue Feb  4 2014 dl8fcl@darc.de
- update to version 2.1.02
* Tue Oct 29 2013 dl8fcl@darc.de
- update to version 2.1.01
* Mon Jul 29 2013 dl8fcl@darc.de
- update to version 2.1.00
* Fri May 10 2013 dl8fcl@darc.de
- update to version 2.0.00
  improments to the NBEMS suite
* Sun Nov 18 2012 dl8fcl@darc.de
- update to version 1.0.01, Maintenance release
* Mon Nov  5 2012 dl8fcl@darc.de
- import into buildservice
